@@ -1,6 +1,6 @@
 test_that("st_font returns as expected when optional packages are installed", {
-  skip_on_appveyor()
   skip_on_cran()
+  skip_on_os(c("linux", "mac"))
 
   x <- st_font()
   expect_is(x, "character")
